@@ -19,6 +19,34 @@ class Act(models.Model):
             def __init__(self):
                 pass
 
+    def new_act(self, act_name=None):
+        bs_home = os.path.dirname(os.path.abspath(backstage.__file__))
+        if act_name is None:
+            err = 'Name of new act required'
+            print err
+            return False
+        act_skel = os.path.join(bs_home, 'skel/act')
+        act_path = os.path.join(self.PROJECT_ROOT, 'acts/%s' % act_name)
+        try:
+            shutil.copytree(act_skel, act_path)
+        except:
+            print 'error copying act skel'
+            raise
+            return False
+        print 'Created Act %s at %s' % (act_name, act_path)
+
+
+class Site(models.Model):
+    django_site = models.ForeignKey(django.contrib.sites.models.Site)
+    gunicorn_port = models.IntegerField(default=0)
+    uwsgi_port = models.IntegerField(default=0)
+    hostnames = models.TextField(default='')
+    active = models.BooleanField(default=True)
+
+    class Meta():
+        db_table = 'backstage_project'
+
+
 class Stage(models.Model):
     """A Stage is an environment in which your Act can run,
     just as a musical Stage is a physical space where an Act can play music.
