@@ -111,11 +111,14 @@ class Project():
 
     def build_virtualenv(self):
         """build the virtual environment for this backstage project"""
+        cwd = os.getcwd()
         venvdir = os.path.join(self.PROJECT_ROOT,'venv')
         cmd = '%s/build_virtualenv' % (venvdir)
         st = os.stat(cmd)
         os.chmod(cmd, st.st_mode | stat.S_IEXEC)
+        os.chdir(venvdir)
         subprocess.call(cmd)
+        os.chdir(cwd)
         return
 
 def copy_project_skel(project_path):
