@@ -5,7 +5,7 @@ import sys
 
 # Corrects some pathing issues in various contexts, such as cron jobs,
 # and the project layout still being in Django 1.3 format.
-from skel.settings import PROJECT_ROOT, PROJECT_DIRNAME, PROJECT_PATH
+from settings import PROJECT_ROOT, PROJECT_DIRNAME, PROJECT_PATH
 os.chdir(PROJECT_ROOT)
 sys.path.insert(0, PROJECT_ROOT)
 sys.path.insert(1, PROJECT_PATH)
